/// <reference types="react" />
import { IRenderMime } from '@jupyterlab/rendermime-interfaces';
import { INotebookContent } from '@jupyterlab/nbformat';
import { ServiceManager } from '@jupyterlab/services';
import { Lite, Kernel } from './../../jupyter';
import { ICellSidebarProps } from './cell/sidebar/CellSidebarWidget';
import { INotebookToolbarProps } from './toolbar/NotebookToolbar';
import { OnKernelConnection } from '../../state';
import './Notebook.css';
export type ExternalIPyWidgets = {
    name: string;
    version: string;
};
export type BundledIPyWidgets = ExternalIPyWidgets & {
    module: any;
};
export type INotebookProps = {
    CellSidebar?: (props: ICellSidebarProps) => JSX.Element;
    Toolbar?: (props: INotebookToolbarProps) => JSX.Element;
    cellMetadataPanel: boolean;
    cellSidebarMargin: number;
    height?: string;
    id: string;
    lite?: Lite;
    kernel?: Kernel;
    maxHeight?: string;
    nbformat?: INotebookContent;
    nbgrader: boolean;
    onKernelConnection?: OnKernelConnection;
    path?: string;
    readonly: boolean;
    renderId: number;
    renderers: IRenderMime.IRendererFactory[];
    serverless: boolean;
    serviceManager?: ServiceManager.IManager;
    url?: string;
    /**
     * The Kernel Id to use, as defined in the Kernel API.
     */
    useRunningKernelId?: string;
    /**
     * The index (aka position) of the Kernel to use in the list of kernels.
     */
    useRunningKernelIndex?: number;
};
/**
 * This component creates a Notebook as a collection of cells
 * with sidebars.
 *
 * @param props The notebook properties.
 * @returns A Notebook React.js component.
 */
export declare const Notebook: {
    (props: INotebookProps): import("react/jsx-runtime").JSX.Element;
    defaultProps: Partial<INotebookProps>;
};
export default Notebook;
